==> apache-uniffle-0.7.0-incubating-src.tar.gz: apache-uniffle-0.7.0-incubating-src/common/src/main/java/org/apache/uniffle/common/metrics/MetricReporterFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.uniffle.common.metrics;

import java.lang.reflect.Constructor;

import org.apache.commons.lang3.StringUtils;

import org.apache.uniffle.common.config.RssBaseConf;
import org.apache.uniffle.common.config.RssConf;

public class MetricReporterFactory {

  public static MetricReporter getMetricReporter(RssConf conf, String instanceId) throws Exception {
    String name = conf.get(RssBaseConf.RSS_METRICS_REPORTER_CLASS);
    if (StringUtils.isEmpty(name)) {
      return null;
    }
    Class<?> klass = Class.forName(name);
    Constructor<?> constructor;
    constructor = klass.getConstructor(conf.getClass(), instanceId.getClass());
    return (AbstractMetricReporter) constructor.newInstance(conf, instanceId);
  }
}

==> apache-uniffle-0.7.1-incubating-src.tar.gz: apache-uniffle-0.7.1-incubating-src/common/src/main/java/org/apache/uniffle/common/metrics/MetricReporterFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.uniffle.common.metrics;

import java.lang.reflect.Constructor;

import org.apache.commons.lang3.StringUtils;

import org.apache.uniffle.common.config.RssBaseConf;
import org.apache.uniffle.common.config.RssConf;

public class MetricReporterFactory {

  public static MetricReporter getMetricReporter(RssConf conf, String instanceId) throws Exception {
    String name = conf.get(RssBaseConf.RSS_METRICS_REPORTER_CLASS);
    if (StringUtils.isEmpty(name)) {
      return null;
    }
    Class<?> klass = Class.forName(name);
    Constructor<?> constructor;
    constructor = klass.getConstructor(RssConf.class, String.class);
    return (AbstractMetricReporter) constructor.newInstance(conf, instanceId);
  }
}
